<?php

namespace backend\controllers;

use Yii;
use backend\models\District;
use backend\models\DistrictSearch;
use yii\filters\AccessControl;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\helpers\Url;

/**
 * DistrictController implements the CRUD actions for District model.
 */
class DistrictController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'actions' => ['login', 'error'],
                        'allow' => true,
                    ],
                    [
                        'actions' => ['create','delete','index','view','logout'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                    [
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all District models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new DistrictSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        $dataProvider->pagination->pageSize=10;

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single District model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new District model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new District();
        $searchModel = new DistrictSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        $dataProvider->pagination->pageSize=10;
        if ($model->load(Yii::$app->request->post())) {
            $check = District::find()->select(['id'])->Where(['district_name' => $model->district_name])->asArray()->one();
            if (!empty($check['id'])) {
                $update_status = Yii::$app->db->createCommand()
                        ->update('district', ['status' => 1], ['id' => $check['id']])
                        ->execute();
            }else{
             $model->updated_at = date("Y-m-d h:i:s");
            $model->district_name = htmlspecialchars_decode($model->district_name);
            $languageArray="";
            if(!empty($_REQUEST['language_value'])){
                $languageArray = array_combine($_REQUEST['language'], $_REQUEST['language_value']);
            }
            
            $langMasterArray = array();
            if (!empty($languageArray) && count($languageArray) > 0) {
                foreach ($languageArray as $key => $value) {
                    $langMasterArray[][$key] = $value;
                }
            }
            $langMasterArray[]['En'] = htmlspecialchars_decode($model->district_name);
            $languageArrayJson = json_encode($langMasterArray, true);
            $model->language = $languageArrayJson;
            $model->district_name = htmlspecialchars_decode($model->district_name);
            $model->save();   
            }
            
            keepLogActionWiseWeb(json_encode(Yii::$app->request->post()), true, true);
            return $this->redirect(['create', 'id' => $model->id,
                        'searchModel' => $searchModel,
                        'dataProvider' => $dataProvider,
            ]);
     
        }

        return $this->render('create', [
            'model' => $model,
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Updates an existing District model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);
        $searchModel = new DistrictSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        if ($model->load(Yii::$app->request->post())) {
         
            $model->updated_at = date("Y-m-d h:i:s");
            $model->district_name = htmlspecialchars_decode($model->district_name);
            $languageArray="";
            if(!empty($_REQUEST['language_value'])){
                $languageArray = array_combine($_REQUEST['language'], $_REQUEST['language_value']);
            }
            
            $langMasterArray = array();
            if (!empty($languageArray) && count($languageArray) > 0) {
                foreach ($languageArray as $key => $value) {
                    $langMasterArray[][$key] = $value;
                }
            }
            $langMasterArray[]['En'] = htmlspecialchars_decode($model->district_name);
            $languageArrayJson = json_encode($langMasterArray, true);
            $model->language = $languageArrayJson;
            $model->district_name = htmlspecialchars_decode($model->district_name);
            $model->save();
            keepLogActionWiseWeb(json_encode(Yii::$app->request->post()), true, true);
            return $this->redirect(['create', 'id' => $model->id,
                        'searchModel' => $searchModel,
                        'dataProvider' => $dataProvider,
            ]);
     
        }
        return $this->render('create', [
            'model' => $model,
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Deletes an existing District model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        //$mod = $this->findModel($id);
        $model = $this->findModel($id);
        $model->updated_at = date('Y-m-d H:i:s');
        $model->status = 0;
        try {
            if ($model->save(false)) {
                keepLogActionWiseWeb(json_encode($model->attributes),true, true);
                return $this->redirect(['create']);
            }
        } catch (\Exception $e) {
            echo("<script>alert('Request denied because its related data exists'); window.location = 'index';</script>");
        }

        
    }

    /**
     * Finds the District model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return District the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = District::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException(Yii::t('app', 'The requested page does not exist.'));
    }

    
    public function actionGetDistrict(){
        $request = Yii::$app->request;
        $postData = $request->post();
        $path = Url::to('@app/data/all-district.json');
        $json = json_decode(file_get_contents($path),true);
        
        foreach ($json['district'] as $key => $value) {
          if($postData['id'] == $value['state_id']){
          echo "<option  value='" . $value['label'] . "'  >".$value['label'] ."</option>";
          }
        }
    }

}
