<?php

namespace backend\controllers;

use Yii;
use backend\models\Product;
use backend\models\ProductSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\UploadedFile;   

/**
 * ProductController implements the CRUD actions for Product model.
 */
class ProductController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all Product models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new ProductSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        $dataProvider->pagination->pageSize=10;
        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Product model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Product model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
   public function actionCreate()
    {
       $model = new Product();
       
        if ($model->load(Yii::$app->request->post())) {
           
                $ImgDir = \Yii::getAlias('@webroot') . '/upload';
                $dirname = "product";
                $filename = $ImgDir."/".$dirname."/";

                if (!is_dir($filename )) {
                    mkdir($ImgDir."/" . $dirname);
                    chmod($ImgDir."/" . $dirname, 0777); 
                } 
                $image_id = rand(99999, 100000);
                //-------upload first logo--------------------------------------
                $image1 = UploadedFile::getInstance($model, 'product_image');
                $image2 = UploadedFile::getInstance($model, 'product_secondary_image');
                
                $product_image = $image_id . "_" . $image1;
                $product_image2 = $image_id . "sec_" . $image2;
                $target_path = $ImgDir . '/product';
                $image1->saveAs($target_path . '/' . $product_image);
                $image2->saveAs($target_path . '/' . $product_image2);
                $model->product_image = $product_image;
                $model->product_secondary_image = $product_image2;
                $model->save();
            

            keepLogActionWiseWeb(json_encode(Yii::$app->request->post()), true, true);
             return $this->redirect(['index', 
            ]);
        }

        return $this->render('create', [
                    'model' => $model,
                   
        ]);
    }

    /**
     * Updates an existing Product model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        $image = $model->product_image;
        $image2 = $model->product_secondary_image;
        if ($model->load(Yii::$app->request->post())) {
         
                if (!empty($_FILES['Product']['name']['product_image'])) {
                    $ImgDir = \Yii::getAlias('@webroot') . '/upload';
                    $product_id = rand(99999, 100000);
                    $image1 = UploadedFile::getInstance($model, 'product_image');
                    $product_image = $product_id . "_" . $_FILES['Product']['name']['product_image'];
                    $target_path = $ImgDir . '/product';
                    $image1->saveAs($target_path . '/' . $product_image);
                    $model->product_image = $product_image;
                } else {
                    $model->product_image = $image;
                }
                if (!empty($_FILES['Product']['name']['product_secondary_image'])) {
                    $ImgDir = \Yii::getAlias('@webroot') . '/upload';
                    $product_id = rand(99999, 100000);
                    $image2 = UploadedFile::getInstance($model, 'product_secondary_image');
                    $product_image2 = $product_id . "sec_" . $_FILES['Product']['name']['product_secondary_image'];
                    $target_path = $ImgDir . '/product';
                    $image2->saveAs($target_path . '/' . $product_image2);
                    $model->product_secondary_image = $product_image2;
                  
                }else {
                    $model->product_secondary_image = $image2;
                   
                }
                
               $model->save();
                keepLogActionWiseWeb(json_encode(Yii::$app->request->post()), true, true);
                return $this->redirect(['index'
                ]);
            
        }
        return $this->render('create', [
                    'model' => $model,
                   
        ]);
    }
    /**
     * Deletes an existing Product model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the Product model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Product the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Product::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
}
