<?php

namespace backend\controllers;

use Yii;
use yii\web\Controller;
use yii\filters\VerbFilter;
use yii\filters\AccessControl;
use common\models\LoginForm;

/**
 * Site controller
 */
class SiteController extends Controller {

    /**
     * {@inheritdoc}
     */
    public $enableCsrfValidation = false;

    public function behaviors() {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'actions' => ['login', 'error'],
                        'allow' => true,
                    ],
                    [
                        'actions' => ['create', 'delete', 'index', 'view', 'logout'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                    [
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function actions() {
        return [
            'error' => [
                'class' => 'yii\web\ErrorAction',
            ],
        ];
    }

    /**
     * Displays homepage.
     *
     * @return string
     */
    public function actionIndex() {
        session_regenerate_id(true);

        $totalUser = \backend\models\User::find()->where(["status" => "1"])->andWhere(["level_id" => "2"])->count();
        $totalProducts = \backend\models\Product::find()->count();
      
        return $this->render('index', [
                    "totalUser" => $totalUser,
                    "totalProducts" => $totalProducts,
                 
        ]);
    }

    public function actionComingSoon() {
        return $this->render('coming_soon');
    }

    public function actionPassUpdate() {
        return $this->render('passchange');
    }

    /**
     * Login action.
     *
     * @return string
     */
    public function actionLogin() {

        $post = \Yii::$app->request->post();
        $session = Yii::$app->session;
        $model = new LoginForm();
        if ($model->load(Yii::$app->request->post()) && $model->login()) {
            if (!$session->isActive) {
                $session->open();
            }
            $session->set("login_info", $model);
            ob_start();
            return $this->goBack();
        } else {
            return $this->render('login', [
                        'model' => $model,
            ]);
        }
    }

    public function beforeAction($action) {
        $this->enableCsrfValidation = false;
        return parent::beforeAction($action);
    }

    /**
     * Logout action.
     *
     * @return string
     */
    public function actionLogout() {
        $session = Yii::$app->session;
        Yii::$app->user->logout();
        $session->destroy();
        return $this->goHome();
    }

  
    private function getStateDetail($location) {

        foreach ($location as $value) {
            $loc[] = $value['location_id'];
        }
        $query = new \yii\db\Query;
        $query->select(['state.state_name as state_name'
                ])
                ->from('state')
                ->where(['state.id' => $loc])
                ->andWhere(['state.status' => 1]);
        $command = $query->createCommand();
        $masterData = $command->queryAll();
        return isset($masterData) && $masterData != "" ? $masterData : "";
    }

    private function getDistrictDetail($location) {

        foreach ($location as $value) {
            $loc[] = $value['location_id'];
        }
        $query = new \yii\db\Query;
        $query->select(['state.state_name as state_name',
                    'district.district_name as district_name'
                ])
                ->from('district')
                ->innerJoin('state', "state.id = district.state_id")
                ->where(['district.id' => $loc])
                ->andWhere(['district.status' => 1]);
        $command = $query->createCommand();
        $masterData = $command->queryAll();
        return isset($masterData) && $masterData != "" ? $masterData : "";
    }

  
    
    public function actionPasswordUpdate() {
        $query = new \yii\db\Query;
        $query->select(['user.username', 'user.password_hash'
                ])
                ->from('user');

        $command = $query->createCommand();
        $masterData = $command->queryAll();
        $conn = Yii::$app->getDb();
        foreach ($masterData as $value) {

            $pass = $value['password_hash'];
            $passHas = password_hash($value['password_hash'], PASSWORD_DEFAULT);
            $updatePass = 'UPDATE user SET password_hash = "' . $passHas . '"  where username = "' . $value['username'] . '"' . ';';
            $runquery = $conn->createCommand($updatePass)->execute();
        }
    }

    public function actionEvent() {

        return $this->render('event');
    }

    public function actionToken() {

        return $this->render('token');
    }

    public function actionTokenManagement() {

        return $this->render('event');
    }

}
