<?php

namespace backend\controllers;

use Yii;
use backend\models\Slider;
use backend\models\SliderSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\UploadedFile;

/**
 * SliderController implements the CRUD actions for Slider model.
 */
class SliderController extends Controller {

    /**
     * {@inheritdoc}
     */
    public function behaviors() {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all Slider models.
     * @return mixed
     */
    public function actionIndex() {
        $searchModel = new SliderSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
                    'searchModel' => $searchModel,
                    'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Slider model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id) {
        return $this->render('view', [
                    'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Slider model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate() {
        $model = new Slider();
        $searchModel = new SliderSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        $dataProvider->pagination->pageSize = 10;
        if ($model->load(Yii::$app->request->post())) {
           
           
            
                $ImgDir = \Yii::getAlias('@webroot') . '/upload';
                $dirname = "slider";
                $filename = $ImgDir."/".$dirname."/";

                if (!is_dir($filename )) {
                    mkdir($ImgDir."/" . $dirname);
                    chmod($ImgDir."/" . $dirname, 0777); 
                } 
                $image_id = rand(99999, 100000);
                //-------upload first logo--------------------------------------
                $image1 = UploadedFile::getInstance($model, 'slider_image');
                $slider_image = $image_id . "_" . $image1;
                $target_path = $ImgDir . '/slider';
                $image1->saveAs($target_path . '/' . $slider_image);
                $model->slider_image = $slider_image;
                $model->save();
            

            keepLogActionWiseWeb(json_encode(Yii::$app->request->post()), true, true);
            return $this->redirect(['create'
            ]);
        }

        return $this->render('create', [
                    'model' => $model,
                    'searchModel' => $searchModel,
                    'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Updates an existing Slider model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id) {
        $model = $this->findModel($id);

        $searchModel = new SliderSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        $slider = $model->slider_image;
        if ($model->load(Yii::$app->request->post())) {
            if ($model->save()) {
                if (!empty($_FILES['Slider']['name']['slider_image'])) {
                    $ImgDir = \Yii::getAlias('@webroot') . '/upload';
                    $slider_id = rand(99999, 100000);
                    $image1 = UploadedFile::getInstance($model, 'slider_image');
                    $slider = $slider_id . "_" . $_FILES['Slider']['name']['slider_image'];
                    $target_path = $ImgDir . '/slider';
                    $image1->saveAs($target_path . '/' . $slider);
                    $model->slider_image = $slider;
                    $model->save();
                } else {
                    $model->slider_image = $slider;
                    $model->save();
                }
               
                keepLogActionWiseWeb(json_encode(Yii::$app->request->post()), true, true);
                return $this->redirect(['create', 'id' => $model->id,
                            'searchModel' => $searchModel,
                            'dataProvider' => $dataProvider,
                ]);
            }
        }
        return $this->render('create', [
                    'model' => $model,
                    'searchModel' => $searchModel,
                    'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Deletes an existing Partner model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id) {
        $model = $this->findModel($id);
        //$model->updated_at = date('Y-m-d H:i:s');
        $model->status = 0;
        try {
            if ($model->save(false)) {
                keepLogActionWiseWeb(json_encode($model->attributes), true, true);
                return $this->redirect(['create']);
            }
        } catch (\Exception $e) {
            echo("<script>alert('Request denied because its related data exists'); window.location = 'index';</script>");
        }
    }

    /**
     * Finds the Partner model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Partner the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id) {
        if (($model = Slider::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }

}
