<?php

namespace backend\controllers;

use Yii;
use backend\models\State;
use backend\models\User;
use backend\models\StateSearch;
use yii\filters\AccessControl;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;

/**
 * StateController implements the CRUD actions for State model.
 */
class StateController extends Controller {

    /**
     * @inheritdoc
     */
    public function behaviors() {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'actions' => ['login', 'error'],
                        'allow' => true,
                    ],
                    [
                        'actions' => ['create', 'delete', 'index', 'view', 'logout'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                    [
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all State models.
     * @return mixed
     */
    public function actionIndex() {
        $searchModel = new StateSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        $dataProvider->pagination->pageSize = 10;

        return $this->render('index', [
                    'searchModel' => $searchModel,
                    'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single State model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id) {

        return $this->render('view', [
                    'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new State model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate() {

        $model = new State();
        $searchModel = new StateSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        $dataProvider->pagination->pageSize = 10;
        $model->user_id = Yii::$app->user->identity->id;
        if ($model->load(Yii::$app->request->post())) {
            $check = State::find()->select(['id'])->Where(['state_id' => $model->state_id])->asArray()->one();
            if (!empty($check['id'])) {
                $update_status = Yii::$app->db->createCommand()
                        ->update('state', ['status' => 1], ['id' => $check['id']])
                        ->execute();
            } else {
                $languageArray = array_combine($_REQUEST['language'], $_REQUEST['language_value']);
                $langMasterArray = array();
                if (count($languageArray) > 0) {
                    foreach ($languageArray as $key => $value) {
                        $langMasterArray[][$key] = $value;
                    }
                }
                $langMasterArray[]['En'] = htmlspecialchars_decode($model->state_name);
                $languageArrayJson = json_encode($langMasterArray, true);
                $model->language = $languageArrayJson;
                $model->state_name = htmlspecialchars_decode($model->state_name);
                $model->save();
            }

            keepLogActionWiseWeb(json_encode(Yii::$app->request->post()), true, true);
            return $this->redirect(['create', 'id' => $model->id,
                        'searchModel' => $searchModel,
                        'dataProvider' => $dataProvider,
            ]);
        }

        return $this->render('create', [
                    'model' => $model,
                    'searchModel' => $searchModel,
                    'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Updates an existing State model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id) {

        $model = $this->findModel($id);
        $searchModel = new StateSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        if ($model->load(Yii::$app->request->post())) {

            $model->updated_at = date("Y-m-d h:i:s");
            $model->state_name = htmlspecialchars_decode($model->state_name);
            $languageArray = "";
            if (!empty($_REQUEST['language_value'])) {
                $languageArray = array_combine($_REQUEST['language'], $_REQUEST['language_value']);
            }

            $langMasterArray = array();
            if (!empty($languageArray) && count($languageArray) > 0) {
                foreach ($languageArray as $key => $value) {
                    $langMasterArray[][$key] = $value;
                }
            }
            $langMasterArray[]['En'] = htmlspecialchars_decode($model->state_name);
            $languageArrayJson = json_encode($langMasterArray, true);
            $model->language = $languageArrayJson;
            $model->state_name = htmlspecialchars_decode($model->state_name);
            $model->save();
            keepLogActionWiseWeb(json_encode(Yii::$app->request->post()), true, true);
            return $this->redirect(['create', 'id' => $model->id,
                        'searchModel' => $searchModel,
                        'dataProvider' => $dataProvider,
            ]);
        }
        return $this->render('create', [
                    'model' => $model,
                    'searchModel' => $searchModel,
                    'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Deletes an existing State model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id) {
        $model = $this->findModel($id);
        $model->updated_at = date('Y-m-d H:i:s');
        $model->status = 0;
        try {
            if ($model->save(false)) {
                keepLogActionWiseWeb(json_encode($model->attributes), true, true);
                return $this->redirect(['create']);
            }
        } catch (\Exception $e) {
            echo("<script>alert('Request denied because its related data exists'); window.location = 'index';</script>");
        }
    }

    /**
     * Finds the State model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return State the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id) {
        if (($model = State::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException(Yii::t('app', 'The requested page does not exist.'));
    }

}
