<?php

namespace backend\controllers;

use Yii;
use backend\models\SubCategory;
use backend\models\SubCategoryearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\UploadedFile;       

/**
 * SubCategoryController implements the CRUD actions for SubCategory model.
 */
class SubCategoryController extends Controller
{
    /**
     * {@inheritdoc}
     */
    public function behaviors()
    {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all SubCategory models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new SubCategoryearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        $dataProvider->pagination->pageSize=10;

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single SubCategory model.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new SubCategory model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
      
        $model = new SubCategory();
       
        if ($model->load(Yii::$app->request->post())) {
           
                $ImgDir = \Yii::getAlias('@webroot') . '/upload';
                $dirname = "subcategory";
                $filename = $ImgDir."/".$dirname."/";

                if (!is_dir($filename )) {
                    mkdir($ImgDir."/" . $dirname);
                    chmod($ImgDir."/" . $dirname, 0777); 
                } 
                $image_id = rand(99999, 100000);
                //-------upload first logo--------------------------------------
                $image1 = UploadedFile::getInstance($model, 'image');
                $subcat_image = $image_id . "_" . $image1;
                $target_path = $ImgDir . '/subcategory';
                $image1->saveAs($target_path . '/' . $subcat_image);
                $model->image = $subcat_image;
                $model->save();
            

            keepLogActionWiseWeb(json_encode(Yii::$app->request->post()), true, true);
             return $this->redirect(['index', 
            ]);
        }

        return $this->render('create', [
                    'model' => $model,
                   
        ]);
    }

    /**
     * Updates an existing SubCategory model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        $image = $model->image;
        if ($model->load(Yii::$app->request->post())) {
           
                if (!empty($_FILES['SubCategory']['name']['image'])) {
                    $ImgDir = \Yii::getAlias('@webroot') . '/upload';
                    $subcategory_id = rand(99999, 100000);
                    $image1 = UploadedFile::getInstance($model, 'image');
                    $subcat_image = $subcategory_id . "_" . $_FILES['SubCategory']['name']['image'];
                    $target_path = $ImgDir . '/subcategory';
                    $image1->saveAs($target_path . '/' . $subcat_image);
                    $model->image = $subcat_image;
                    $model->save();
                } else {
                    $model->image = $image;
                    $model->save();
                }
               
                keepLogActionWiseWeb(json_encode(Yii::$app->request->post()), true, true);
                return $this->redirect(['index'
                ]);
            
        }
        return $this->render('create', [
                    'model' => $model,
                   
        ]);
    }

    /**
     * Deletes an existing SubCategory model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     * @throws NotFoundHttpException if the model cannot be found
     */
    public function actionDelete($id)
    {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the SubCategory model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return SubCategory the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = SubCategory::findOne($id)) !== null) {
            return $model;
        }

        throw new NotFoundHttpException('The requested page does not exist.');
    }
    public function actionGetSubcategryList(){
        $request = Yii::$app->request;
        $post = $request->post();

        if (isset($post['key']) && $post['key'] != "") {
            $data = SubCategory::find()->select(['id', 'name'])->asArray()->where(['id' => $post['value']])->andWhere(['status'=>1])->all();
            if (empty($data)) {
                $data = [];
            }
        }
        echo json_encode($data);
       
    }
}
