<?php

namespace backend\models;

use Yii;

/**
 * This is the model class for table "category".
 *
 * @property int $id
 * @property string $name
 * @property string $status
 * @property string $created_date
 * @property string $updated_date
 * @property int $created_by
 *
 * @property User $createdBy
 * @property IssueCategory[] $issueCategories
 * @property IssueSubCategory[] $issueSubCategories
 */
class Category extends \yii\db\ActiveRecord {

    /**
     * {@inheritdoc}
     */
    public static function tableName() {
        return 'category';
    }

    /**
     * {@inheritdoc}
     */
    public function rules() {
        return [
            [['status'], 'string'],
            [['created_date', 'updated_date'], 'safe'],
            [['created_by'], 'required'],
            [['created_by'], 'integer'],
            [['name'], 'string', 'max' => 250,],
            [['name'], 'unique'],
            [['name'], 'trim'],
            ['name', 'required', 'message' => 'Name cannot be blank'],
            array('name', 'match',
                'pattern' => '/^[A-Za-z\s]+$/u',
                'message' => 'Name can contain only Alphabets'
            ),
            [['created_by'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['created_by' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels() {
        return [
            'id' => 'ID',
            'name' => 'Name',
            'status' => 'Status',
            'created_date' => 'Created Date',
            'updated_date' => 'Updated Date',
            'created_by' => 'Created By',
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCreatedBy() {
        return $this->hasOne(User::className(), ['id' => 'created_by']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIssueCategories() {
        return $this->hasMany(IssueCategory::className(), ['category_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIssueSubCategories() {
        return $this->hasMany(IssueSubCategory::className(), ['issue_category_id' => 'id']);
    }

    public function getUser() {
        return $this->hasOne(User::className(), ['id' => 'created_by']);
    }

    public function getCategoryName($id) {
        return $this->find()->select("name")->where(["id" => $id])->one()->name;
    }

}
