<?php

namespace backend\models;

use Yii;
use yii\base\Model;
use yii\data\ActiveDataProvider;
use backend\models\District;

/**
 * DistrictSearch represents the model behind the search form of `backend\models\District`.
 */
class DistrictSearch extends District {

    /**
     * @inheritdoc
     */
    public function rules() {
        return [
            [['id', 'status'], 'integer'],
            [['state_id', 'district_name', 'language', 'created_at', 'updated_at'], 'safe'],
            array('district_name', 'filter', 'filter'=>'trim'),
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios() {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params) {
        $query = District::find()
                ->joinWith("state")->where(['district.status'=>'1']);
        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            'sort' => ['defaultOrder' => ['id' => SORT_DESC]]
        ]);
        $dataProvider->sort->attributes['state_id'] = [
            'asc' => ['state.state_name' => SORT_ASC],
            'desc' => ['state.state_name' => SORT_DESC]
        ];

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'id' => $this->id,
            'district.status' => $this->status,
        ]);

        $query->andFilterWhere(['like', 'district_name', $this->district_name])
                ->andFilterWhere(['like', 'state.state_name', trim($this->state_id)])
                ->andFilterWhere(['like', 'DATE_FORMAT(district.created_at,"%d-%m-%Y")', $this->created_at])
                ->andFilterWhere(['like', 'DATE_FORMAT(district.updated_at,"%d-%m-%Y")', $this->updated_at]);
        return $dataProvider;
    }

}
