<?php

namespace backend\models;

use Yii;

/**
 * This is the model class for table "product".
 *
 * @property int $id
 * @property string $name
 * @property int $category_id
 * @property int $subcategory_id
 * @property string $product_code
 * @property string $product_description
 * @property string $product_image
 * @property string $mrp
 * @property string $selling_price
 * @property string $discount
 * @property string $status
 * @property string $created_at
 * @property string $updated_at
 * @property int $rating
 * @property string $is_new
 * @property string $show_home_page
 *
 * @property SubCategory $subcategory
 * @property Category $category
 */
class Product extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'product';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['name', 'category_id', 'subcategory_id', 'product_code', 'product_description','product_secondary_image', 'product_image', 'mrp', 'selling_price', 'discount', 'status', 'rating'], 'required'],
            [['category_id', 'subcategory_id', 'rating'], 'integer'],
            [['product_description', 'status', 'is_new', 'show_home_page'], 'string'],
            [['mrp', 'selling_price', 'discount'], 'number'],
            [['created_at', 'updated_at'], 'safe'],
            [['name', 'product_image','product_secondary_image'], 'string', 'max' => 255],
            [['product_code'], 'string', 'max' => 50],
            [['subcategory_id'], 'exist', 'skipOnError' => true, 'targetClass' => SubCategory::className(), 'targetAttribute' => ['subcategory_id' => 'id']],
            [['category_id'], 'exist', 'skipOnError' => true, 'targetClass' => Category::className(), 'targetAttribute' => ['category_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'name' => 'Name',
            'category_id' => 'Category ID',
            'subcategory_id' => 'Subcategory ID',
            'product_code' => 'Product Code',
            'product_description' => 'Product Description',
            'product_image' => 'Product Image',
            'product_secondary_image' => 'Product Secondary Image',
            
            'mrp' => 'Mrp',
            'selling_price' => 'Selling Price',
            'discount' => 'Discount',
            'status' => 'Status',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
            'rating' => 'Rating',
            'is_new' => 'Is New',
            'show_home_page' => 'Show Home Page',
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getSubcategory()
    {
        return $this->hasOne(SubCategory::className(), ['id' => 'subcategory_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCategory()
    {
        return $this->hasOne(Category::className(), ['id' => 'category_id']);
    }
}
