<?php

namespace backend\models;

use Yii;

/**
 * This is the model class for table "user".
 *
 * @property int $id
 * @property string $name
 * @property string $username
 * @property string $mobile
 * @property int $institution_id
 * @property int $level_id
 * @property string $password_hash
 * @property string $password_reset_token
 * @property string $email
 * @property string $language
 * @property string $auth_key
 * @property int $status
 * @property string $created_at
 * @property string $updated_at
 * @property string $changed_password_once
 * @property string $confirm_password
 * @property int $otp
 * @property string $otp_status 0=>otp expired,1=>otp active
 * @property string $dob
 * @property string $gender
 * @property string $photo
 * @property string $address
 * @property int $district_id
 * @property string $latitude
 * @property string $longitude
 *
 * @property Action[] $actions
 * @property Category[] $categories
 * @property ChangeMaster[] $changeMasters
 * @property Event[] $events
 * @property Institution[] $institutions
 * @property Issue[] $issues
 * @property IssueResponse[] $issueResponses
 * @property ReportedIssues[] $reportedIssues
 * @property Token[] $tokens
 * @property Institution $institution
 * @property District $district
 */
class User extends \yii\db\ActiveRecord
{
    /**
     * {@inheritdoc}
     */
    public static function tableName()
    {
        return 'user';
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return [
            [['username', 'institution_id', 'dob', 'gender', 'photo', 'address', 'district_id', 'latitude', 'longitude'], 'required'],
            [['institution_id', 'level_id', 'status', 'otp', 'district_id'], 'integer'],
            [['created_at', 'updated_at', 'dob','other_institution'], 'safe'],
            [['otp_status'], 'string'],
            [['username'], 'unique'],
            [['latitude', 'longitude'], 'number'],
            [['name', 'changed_password_once', 'confirm_password'], 'string', 'max' => 100],
            [['username', 'password_hash', 'password_reset_token', 'email', 'photo', 'address'], 'string', 'max' => 255],
            [['mobile'], 'string', 'max' => 10],
            [['language'], 'string', 'max' => 50],
            [['auth_key'], 'string', 'max' => 32],
            [['gender'], 'string', 'max' => 20],
            [['institution_id'], 'exist', 'skipOnError' => true, 'targetClass' => Institution::className(), 'targetAttribute' => ['institution_id' => 'id']],
            [['district_id'], 'exist', 'skipOnError' => true, 'targetClass' => District::className(), 'targetAttribute' => ['district_id' => 'id']],
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'name' => 'Name',
            'username' => 'Username',
            'mobile' => 'Mobile',
            'institution_id' => 'Institution ID',
            'other_institution' => 'Other Institution',
            'level_id' => 'Level ID',
            'password_hash' => 'Password Hash',
            'password_reset_token' => 'Password Reset Token',
            'email' => 'Email',
            'language' => 'Language',
            'auth_key' => 'Auth Key',
            'status' => 'Status',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
            'changed_password_once' => 'Changed Password Once',
            'confirm_password' => 'Confirm Password',
            'otp' => 'Otp',
            'otp_status' => 'Otp Status',
            'dob' => 'Dob',
            'gender' => 'Gender',
            'photo' => 'Photo',
            'address' => 'Address',
            'district_id' => 'District ID',
            'latitude' => 'Latitude',
            'longitude' => 'Longitude',
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getActions()
    {
        return $this->hasMany(Action::className(), ['user_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCategories()
    {
        return $this->hasMany(Category::className(), ['created_by' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getChangeMasters()
    {
        return $this->hasMany(ChangeMaster::className(), ['user_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getEvents()
    {
        return $this->hasMany(Event::className(), ['user_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getInstitutions()
    {
        return $this->hasMany(Institution::className(), ['user_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIssues()
    {
        return $this->hasMany(Issue::className(), ['created_by' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIssueResponses()
    {
        return $this->hasMany(IssueResponse::className(), ['user_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getReportedIssues()
    {
        return $this->hasMany(ReportedIssues::className(), ['user_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getTokens()
    {
        return $this->hasMany(Token::className(), ['user_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getInstitution($id)
    {
      $instName = \backend\models\Institution::find()->select(['name'])->where(['id' => $id])->asArray()->one();
       return $instName['name'];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getDistrict($id)
    {
       
        $distName = \backend\models\District::find()->select(['district_name'])->where(['id' => $id])->asArray()->one();
        return $distName['district_name'];
    }
}
