<?php

use yii\helpers\Html;
use yii\widgets\ActiveForm;
use yii\grid\GridView;
use yii\helpers\ArrayHelper;
use yii\helpers\Url;
use kartik\select2\Select2;
use yii\widgets\Pjax;
use kartik\export\ExportMenu;
use kartik\date\DatePicker;
use backend\models\ReportedIssues;
use backend\models\Action;
use backend\models\ChangeMaster;

/* @var $this yii\web\View */
/* @var $model backend\models\District */
/* @var $form yii\widgets\ActiveForm */
?>
<div class="box">
    <div class="box-header">
<?php
$gridColumnsExcelDownload = [

     [
                    'label' => 'Reported Issue',
                    'attribute' => 'rissue_id',
                    'filter' => ArrayHelper::map(\backend\models\Issue::find()->asArray()->all(), 'rissue_id', 'name'),
                    'value' => function($data) {
                        return getReportissueName($data->rissue_id);
                    }
                ],
    [
        'label' => 'Action & Change',
        'attribute' => 'action_change_id',
        'value' => function($data) {
            if ($data->response_type == 0) {
                return getActionName($data->action_change_id);
            } else if ($data->response_type == 1) {
                return getChangeName($data->action_change_id);
            } else {
                return "";
            }
        }
    ],
    [
        'attribute' => 'response_type',
        'filter' => array("0" => "Action", "1" => "Change"),
        'filterInputOptions' => ['class' => 'form-control', 'id' => null, 'prompt' => 'Response type'],
        'value' => function($data) {
    if ($data->response_type == 0) {
        return "Action";
    } else if ($data->response_type == 1) {
        return "Change";
    } else {
        return "";
    }
}
    ],
    [
        'attribute' => 'location',
        'filter' => array("0" => "On Location", "1" => "Away from location"),
        'filterInputOptions' => ['class' => 'form-control', 'id' => null, 'prompt' => 'Location'],
        'value' => function($data) {
    if ($data->location == 0) {
        return "On Location";
    } else if ($data->location == 1) {
        return "Away from location";
    } else {
        return "";
    }
}
    ],
    'comments',
    'photo',
    [
        'label' => 'Created By',
        'attribute' => 'user_id',
        'value' => 'user.username'
    ],
    [
        'label' => 'Created At',
        'attribute' => 'created',
        'value' => function($data) {
            return (!empty($data->created)) ? date("d-m-Y H:i:s", strtotime($data->created)) : "";
        }
    ],
    [
        'label' => 'Updated At',
        'attribute' => 'updated',
        'value' => function($data) {
            return (!empty($data->updated)) ? date("d-m-Y H:i:s", strtotime($data->updated)) : "";
        }
    ],
];


echo ExportMenu::widget([
    'dataProvider' => $dataProvider,
    'filterModel' => $searchModel,
    'columns' => $gridColumnsExcelDownload,
    'fontAwesome' => true,
    'dropdownOptions' => [
        'label' => 'Download',
        'class' => 'btn btn-default'
    ],
    'filename' => 'Action & Change',
    'target' => ExportMenu::TARGET_SELF,
    'exportConfig' => [
        ExportMenu::FORMAT_TEXT => false,
        ExportMenu::FORMAT_PDF => false,
        ExportMenu::FORMAT_EXCEL => false,
        ExportMenu::FORMAT_EXCEL_X => false,
        ExportMenu::FORMAT_HTML => false,
    ],
])
?>
        <div class="table-responsive">
        <?=
        GridView::widget([
            'dataProvider' => $dataProvider,
            'tableOptions' => ['class' => 'table'],
            'filterModel' => $searchModel,
            'columns' => [
                ['class' => 'yii\grid\SerialColumn', 'header' => 'S.No.', 'headerOptions' => [
                        'style' => 'color:#3c8dbc'],],
                [
                    'label' => 'Reported Issue',
                    //'attribute' => 'rissue_id',
//                    'filter' => ArrayHelper::map(\backend\models\Issue::find()->asArray()->all(), 'rissue_id', 'name'),
                    'value' => function($data) {
                        return getReportissueName($data->rissue_id);
                    }
                ],
                [
                    'label' => 'Action',
                    'attribute' => 'action_change_id',
                    'filter' => ArrayHelper::map(\backend\models\IssueResponse::action(), 'id', 'name'),
                    'filterInputOptions' => ['class' => 'form-control', 'name' => 'IssueResponseSearch[action]', 'prompt' => 'Action'],
                    'value' => function($data) {
                if ($data->response_type == 0) {
                    return getActionName($data->action_change_id);
                } else {
                    return "";
                }
            }
                ],
                [
                    'label' => 'Change',
                    'attribute' => 'action_change_id',
                    'filter' => ArrayHelper::map(\backend\models\IssueResponse::change(), 'id', 'name'),
                    'filterInputOptions' => ['class' => 'form-control', 'name' => 'IssueResponseSearch[change]', 'prompt' => 'Change'],
                    'value' => function($data) {
                if ($data->response_type == 1) {
                    return getChangeName($data->action_change_id);
                } else {
                    return "";
                }
            }
                ],
                [
                    'attribute' => 'response_type',
                    'filter' => array("0" => "Action", "1" => "Change"),
                    'filterInputOptions' => ['class' => 'form-control', 'id' => null, 'prompt' => 'Response type'],
                    'value' => function($data) {
                if ($data->response_type == 0) {
                    return "Action";
                } else if ($data->response_type == 1) {
                    return "Change";
                } else {
                    return "";
                }
            }
                ],
                [
                    'attribute' => 'location',
                    'filter' => array("0" => "On Location", "1" => "Away from location"),
                    'filterInputOptions' => ['class' => 'form-control', 'id' => null, 'prompt' => 'Location'],
                    'value' => function($data) {
                if ($data->location == 0) {
                    return "On Location";
                } else if ($data->location == 1) {
                    return "Away from location";
                } else {
                    return "";
                }
            }
                ],
                // 'comments',
                         [ 'label' => 'District',
                        'value' => function($data) {
                            return getDistrictByUserId($data->user_id);
                        }
                    ],
                [
                    'label' => 'From Date',
                    'attribute' => 'created',
                    'filter' => DatePicker::widget([
                        'name' => 'IssueResponseSearch[created]',
                        'type' => DatePicker::TYPE_INPUT,
                        'options' => ['placeholder' => 'Select Date'],
                        'value' => isset($_GET['IssueResponseSearch']['created']) ? $_GET['IssueResponseSearch']['created'] : "",
                        'pluginOptions' => [
                            'autoclose' => true,
                            'format' => 'dd-mm-yyyy'
                        ]
                    ]),
                    'value' => function($data) {
                return (!empty($data->created)) ? date("d-m-Y H:i:s", strtotime($data->created)) : null;
            }
                ],
                [ 'label' => 'To Date',
                    'attribute' => 'end_date',
                    'filter' => DatePicker::widget([
                        'name' => 'IssueResponseSearch[end_date]',
                        'type' => DatePicker::TYPE_INPUT,
                        'options' => ['placeholder' => 'Select Date'],
                        'value' => isset($_GET['IssueResponseSearch']['end_date']) ? $_GET['IssueResponseSearch']['end_date'] : "",
                        'pluginOptions' => [
                            'autoclose' => true,
                            'format' => 'dd-mm-yyyy'
                        ]
                    ]),
                    'value' => function($data) {
                return (!empty($data->created)) ? date("d-m-Y H:i:s", strtotime($data->created)) : null;
            }],
                [
                    'class' => 'yii\grid\ActionColumn',
                    'header' => 'Action',
                    'template' => '{view}',
                ],
            ],
        ]);
        ?>
        </div>
    </div>
</div>
<?php

function getReportissueName($id) {
    $issueName = ReportedIssues::find()->select(['issue.name'])->join('INNER JOIN', 'issue', 'issue.id =reported_issues.issue_id')
                    ->where(['reported_issues.id' => $id])->asArray()->one();
    return $issueName['name'];
}

function getActionName($id) {
    $actionName = \backend\models\Action::find()->select(['name'])->where(['id' => $id])->asArray()->one();
    return $actionName['name'];
}

function getChangeName($id) {
    $changeName = \backend\models\ChangeMaster::find()->select(['name'])->where(['id' => $id])->asArray()->one();
    return $changeName['name'];
}
?>